@@ -16,26 +16,11 @@ import re
 from types import StringType, UnicodeType, IntType
 from time import sleep, time, strftime
 from threading import Thread
-from mtronic import MSISDNsebenar
+from msisdn import real_msisdn
 from messaging.sms import SmsDeliver, SmsSubmit
-import imp
+import config as conf
 
 
-conf = imp.load_source('conf', 'config.py')
-TIMEOUT = conf.timeout
-
-NUMBERS = ['0','1','2','3','4','5','6','7','8','9']
-MSISDN_NUMBERS = ['+'] + NUMBERS
-DTMF_KEYS = NUMBERS + ['*','#','A','B','C','D']
-
-SMS_PDU, SMS_TEXT = 0, 1
-
-OPERATOR_LIST_FILE = 'operators.txt'
-
-SMS_ALL_PATTERNS = [
-    re.compile(r'^\+CMGL: (.*),"(.*)","(.*)",,"((.*),((.*)(\+|\-)(.*)))"'),
-    re.compile(r'^\+CMGL:(.*),"(.*)","(.*)",(.*),(.*),(.*)')]
-
 ###########
 # Default #
 ###########
@@ -43,7 +28,6 @@ DEVICE = platform.system() == 'Windows' and 'COM1' or '/dev/ttyUSB0'
 BAUD = 115200
 KEEP = False
 
-
 # Lock filename use minicom standard: /var/lock/LCK..ttyUSB0
 # which content is: '     31273 minicom sugiana\n'
 def lockFile(device=DEVICE):
@@ -72,7 +56,7 @@ def fixMSISDN( s ):
     if len(s) < 11:
         return s
     if s[0] == '0':
-        return MSISDNsebenar(s)
+        return real_msisdn(s)
     return '+' + s
 
 def fixNonASCII( s ):
@@ -150,7 +134,6 @@ class Modem:
     def __init__(self, device=DEVICE, baud=BAUD):
         self.__initVars(device)
         pgid = isLive(self.lockFile)
-        # Jangan teruskan bila modem terkunci
         if pgid:
             err = '%s already locked by pid %s' % (device, pgid)
             self.log( err )
@@ -1583,9 +1566,26 @@ def show(data):
     else:
         print data
 
- 
-if __name__ == '__main__':
 
+def search_file(filename):
+    if os.path.exists(filename):
+        return filename
+    return os.path.join(os.path.split(__file__)[0], filename)
+
+
+
+TIMEOUT = conf.timeout
+NUMBERS = ['0','1','2','3','4','5','6','7','8','9']
+MSISDN_NUMBERS = ['+'] + NUMBERS
+DTMF_KEYS = NUMBERS + ['*','#','A','B','C','D']
+SMS_PDU, SMS_TEXT = 0, 1
+OPERATOR_LIST_FILE = search_file('operators.txt')
+SMS_ALL_PATTERNS = [
+    re.compile(r'^\+CMGL: (.*),"(.*)","(.*)",,"((.*),((.*)(\+|\-)(.*)))"'),
+    re.compile(r'^\+CMGL:(.*),"(.*)","(.*)",(.*),(.*),(.*)')]
+
+
+if __name__ == '__main__':
     import getopt
     import sys
 
